<?php
if(!session_id()) session_start();
include('../config.php');
include($rutaPhp.$rutaHtml.'/maqueta/includes.php');


if($_GET['soloComprobarDatosUnicos']) $soloComprobarDatosUnicos=$_GET['soloComprobarDatosUnicos']; else $soloComprobarDatosUnicos=$_POST['soloComprobarDatosUnicos'];


$mostrarIdioma=$_GET['mostraridioma'];
$pedirLote=$_GET['pedirlote'];
$pedirFechaCaducidad=$_GET['pedirfechacaducidad'];
$mostrarPrecinta=$_GET['mostrarprecinta'];

if(isset($_GET['verEnCajas']) && $_GET['verEnCajas']) $verEnCajas=$_GET['verEnCajas'];
else $verEnCajas=$_POST['verEnCajas'];

if(isset($_GET['gestionPaletizado']) && $_GET['gestionPaletizado']) $gestionPaletizado=$_GET['gestionPaletizado'];
else $gestionPaletizado=$_POST['gestionPaletizado'];

//14-02-2023
if(isset($_GET['datoInformadoPalet']) && $_GET['datoInformadoPalet']) $datoInformadoPalet=$_GET['datoInformadoPalet'];
else $datoInformadoPalet=$_POST['datoInformadoPalet'];

if(isset($_GET['datoInformadoLote']) && $_GET['datoInformadoLote']) $datoInformadoLote=$_GET['datoInformadoLote'];
else $datoInformadoLote=$_POST['datoInformadoLote'];

if(isset($_GET['datoInformadoFechaCaducidad']) && $_GET['datoInformadoFechaCaducidad']) $datoInformadoFechaCaducidad=fechaParaProxium(fechaMysql($_GET['datoInformadoFechaCaducidad']));
else $datoInformadoFechaCaducidad=fechaParaProxium(fechaMysql($_POST['datoInformadoFechaCaducidad']));

//Si hay datos de "mantener" son estos los que se priorizan para el listado
if(isset($_GET['mantenerLote']) && $_GET['mantenerLote']) $mantenerLote=$_GET['mantenerLote'];
else if($_POST['mantenerLote']) $datoInformadoLote=$_POST['mantenerLote'];

//if(isset($_GET['mantenerCaducidad']) && $_GET['mantenerCaducidad']) $datoInformadoFechaCaducidad=fechaParaProxium(fechaMysql($_GET['mantenerCaducidad']));
//else if($_POST['mantenerCaducidad']) $datoInformadoFechaCaducidad=fechaParaProxium(fechaMysql($_POST['mantenerCaducidad']));
if(isset($_GET['mantenerCaducidad']) && $_GET['mantenerCaducidad']) $datoInformadoFechaCaducidad=$_GET['mantenerCaducidad'];
else if($_POST['mantenerCaducidad']) $datoInformadoFechaCaducidad=$_POST['mantenerCaducidad'];

if(isset($_GET['mantenerLote']) && $_GET['mantenerLote']) $mantenerLote=$_GET['mantenerLote'];
else if($_POST['mantenerSerie']) $datoInformadoNumSerie=$_POST['mantenerSerie'];

if(isset($_GET['mantenerEntrada']) && $_GET['mantenerEntrada']) $mantenerEntrada=$_GET['mantenerEntrada'];
else if($_POST['mantenerEntrada']) $datoInformadoEntrada=$_POST['mantenerEntrada'];

if(isset($_GET['mantenerDocEntrada']) && $_GET['mantenerDocEntrada']) $mantenerDocEntrada=$_GET['mantenerDocEntrada'];
else if($_POST['mantenerDocEntrada']) $datoInformadoDocEntrada=$_POST['mantenerDocEntrada'];



if($_GET['numPagina']) $numPagina=$_GET['numPagina']; else if($_POST['numPagina']) $numPagina=$_POST['numPagina']; else $numPagina=1;

if( $_GET['permitirSeleccionarLote'] || $_POST['permitirSeleccionarLote'] ) $permitirSeleccionarLote=true; else $permitirSeleccionarLote=false;

//echo '<p>permitirSeleccionarLote GET: '.$_GET['permitirSeleccionarLote'].'</p>';
//echo '<p>permitirSeleccionarLote POST: '.$_POST['permitirSeleccionarLote'].'</p>';
//echo '<p>permitirSeleccionarLote: '.$permitirSeleccionarLote.'</p>';

/*
echo '
<p>
WSListaContUbiLot#Empresa#PARAMETROS</br>
</br>
1-Almacén (*)</br>
2-Empresa (*)</br>
3-Orden de preparación (*)</br>

0   4-Producto (*)</br>D
1   5-Ubicación</br> 1
2   6-Palet</br>
3   7-Regimen (*)</br> 
4	8-Idioma (*)</br>
5	9-Precinta (*)</br>
6	10-Lote</br>
7	11-Caducidad</br>
8	12-Num. serie</br>
9	13-Num entrada</br>
10	14-Lín entrada
</p>
';
*/

if($_GET['traza']=='si') {
	echo '<p>datoInformadoFechaCaducidad: '.$datoInformadoFechaCaducidad.'</p>';
	echo 'GET: '.$_GET['mantenerCaducidad'].'</p>';
	echo 'POST: '.$POST['mantenerCaducidad'].'</p>';
	echo '<p>Parametros originales:</p>';
	print_r($_SESSION['parametros']);
}


$posiciones=array(
	1=>$datoInformadoUbicacion,
	2=>$datoInformadoPalet,
	6=>$datoInformadoLote,
	7=>$datoInformadoFechaCaducidad,
	8=>$datoInformadoNumSerie,
	9=>$datoInformadoEntrada,
	10=>$datoInformadoDocEntrada,
);

if($_GET['traza']=='si') {
	echo '<p>Sustituciones:</p>';
	print_r($posiciones);
}

$temp=explode(';',$_SESSION['parametros']);
$cadenaParametrosNueva='';
foreach($temp as $clave=>$valor) {
	//echo '<p>Evaluamos la posisicion '.$clave.' que originalmente tenía el valor: '.$valor.'</p>';
	if($cadenaParametrosNueva!='') $cadenaParametrosNueva.=';';
	if(array_key_exists($clave,$posiciones)) {
		//echo '<p>Sustituimos por el valor informado o nada '.$posiciones[$clave].'</p>';
		$cadenaParametrosNueva.=$posiciones[$clave]; //la primera posiciones en parametros es la 4 (producto)
	}
	else {
		//echo '<p>Se queda el valor original: '.$valor.'</p>';
		$cadenaParametrosNueva.=$valor;
	}
	
}

if($_GET['traza']=='si') {
	echo '<p>Parametros finales:</p>';
	print_r($cadenaParametrosNueva);
}


//14-05-2026 TAREA INTERNA 75040
$mostrarPaisOrigen=(isset($_SESSION['parametrosSGA']['GestionPaisOrigen']) && $_SESSION['parametrosSGA']['GestionPaisOrigen']=='S');


$peticion='WSListaContUbiLot#'.$_SESSION['empresa'].'#'.$_SESSION['almacen'].';'.$_SESSION['orden']['Empresa'].';'.$_SESSION['orden']['OrdenPreparacion'].';'.$cadenaParametrosNueva.'#'.$numPagina;

$resultado=PedirDatos($wsUsuario,$wsClave,$wsEmpresa,$peticion);

if($_GET['traza']=='si') {
	echo "<p>".$peticion."</p>";
	print_r($resultado[0]['ListaContUbiLot']);
}

$resultado=$resultado[0];

$listado=arreglaArrayPXMobileProxiumResult($resultado['ListaContUbiLot']);

if(!$resultado['Error']) {

	if($soloComprobarDatosUnicos) {
	
		$palet='';
		$ubicacion='';
		$lote='';
		$fechaCaducidad='';
		
		if($_GET['traza']=='si') {
			echo "<p>".$peticion."</p>";
			echo '<p>>>>>>> soloComprobarDatosUnicos</p>';
			echo '<p>>>>>>> MuchasCombinacionesStock: '.$resultado['MuchasCombinacionesStock'].'</p>';
		}
	
		if($resultado['MuchasCombinacionesStock']!='S') {
		
			if($_GET['traza']=='si') {
				echo '<p>cuantos resultados: '.count($listado).'</p>';
				print_r($listado);
				echo '<hr>';
			}
			
			foreach($listado as $contenedor) {
				
				if($palet=='') $palet=$contenedor['Contenedor'];
				else if($palet!=$contenedor['Contenedor']) $palet='';
					
				if($ubicacion=='') {
					if($contenedor['UbicacionAlias']) $ubicacion=$contenedor['UbicacionAlias']; else $ubicacion=$contenedor['Ubicacion'];
				}
				else {
					if($contenedor['UbicacionAlias']) {
						if($ubicacion!=$contenedor['UbicacionAlias']) $ubicacion='';
					}
					else {
						if($ubicacion!=$contenedor['Ubicacion']) $ubicacion='';
					}
				}
					
				if($lote=='') $lote=$contenedor['Lote'];
				else if($lote!=$contenedor['Lote']) $lote='';
					
				if($fechaCaducidad=='') {
					if($contenedor['FechaCaducidad']=='-') $fechaCaducidad=$contenedor['FechaCaducidad'];
					else $fechaCaducidad=formateaTipo($contenedor['FechaCaducidad'],'F');
				}
				else if($fechaCaducidad!=formateaTipo($contenedor['FechaCaducidad'],'F')) $fechaCaducidad='';
				
				if($_GET['traza']=='si') {
					echo '<p>contenedor FechaCaducidad: '.$contenedor['FechaCaducidad'].'</p>';
					echo '<p>contenedor FechaCaducidad formateaTipo: '.formateaTipo($contenedor['FechaCaducidad'],'F').'</p>';
				}
			}
			
		}
		
		echo $palet.'#'.$ubicacion.'#'.$lote.'#'.$fechaCaducidad.'#';
	
	}
	else {
		
		if($_GET['traza']=='si') {
			echo '<p>>>>>>> ELSE soloComprobarDatosUnicos</p>';
		}

		$contador=($numPagina*100)-100+1;
		
		function paginacion() {
		
			global $numPagina;
			global $resultado;
		
			if($resultado['MuchasCombinacionesStock']=='S') {
				?><p class="medio paginacion"><?php if($numPagina==1) { ?><span class="paginacionDeshabilitado">< Página anterior</span><?php } else { ?><a ref="" class="paginacionEnlace" pagina="<?php echo $numPagina-1; ?>">< Página anterior</a><?php } ?> | Página <?php echo $numPagina; ?> de <?php echo $resultado['NumeroTotalPaginas']; ?> | <?php if($numPagina<$resultado['NumeroTotalPaginas']) { ?><a ref="" class="paginacionEnlace" pagina="<?php echo $numPagina+1; ?>">Siguiente página ></a><?php } else { ?><span class="paginacionDeshabilitado">Siguiente página ></span><?php } ?></p><?php
        	}
		
		}

	
		?>
        <img src="<?php echo DIR_IMAGENES; ?>/menu-on.png" alt="Cerrar" class="botonCerrarCombinaciones clicable" id="botonCerrarPequeño" style="position:absolute;top:10px;right:10px;width:40px;height:40px;"/>
        
		<p><strong>Todas las ubicaciones con este producto:</strong></p>
        
        <?php paginacion(); ?>
        
        <table class="tablaFormateada">
		<tr>
			<th></th>
			<th>Ubicación</th>
			<?php if($gestionPaletizado=='S') { ?><th>Contenedor</th><?php } ?>
			<?php if($mostrarIdioma) { ?><th>Idioma</th><?php } ?>
			<?php if($mostrarPrecinta) { ?><th>Precinta</th><?php } ?>
			<?php if($pedirLote) { ?><th>Lote</th><?php } ?>
			<?php if($pedirFechaCaducidad) { ?><th>Fecha Caducidad</th><?php } ?>
            
            <?php if($mostrarPaisOrigen) { ?>
            <th>País origen</th>
            <?php } ?>
            
            <?php if($datoInformadoNumSerie) { ?><th>Nº Serie</th><?php } ?>
            <?php if($datoInformadoEntrada) { ?><th>Entrada</th><?php } ?>
            <?php if($datoInformadoDocEntrada) { ?><th>Documento</th><?php } ?>
            
			<th>Stock</th>
			<?php if($verEnCajas=='S') { ?><th>Cajas</th><?php } ?>
            
            <?php if($permitirSeleccionarLote) { ?>
            <th></th>
            <?php } ?>
            
		</tr>
		<?php
		foreach($listado as $contenedor) {
			?>
			<tr class="selectorLote" lote="<?php echo $contenedor['Lote']; ?>" caducidad="<?php echo formateaTipo($contenedor['FechaCaducidad'],'F'); ?>" contenedor="<?php echo $contenedor['Contenedor']; ?>" ubicacion="<?php if($contenedor['UbicacionAlias']) echo $contenedor['UbicacionAlias']; else echo $contenedor['Ubicacion']; ?>" paisOrigen="<?php if(isset($contenedor['PaisOrigenCodigo'])) echo $contenedor['PaisOrigenCodigo']; ?>">
				<td><?php echo $contador; ?>
				<td><?php if($contenedor['UbicacionAlias']) echo $contenedor['UbicacionAlias']; else echo $contenedor['Ubicacion']; ?></td>
				<?php if($gestionPaletizado=='S') { ?><td><?php echo $contenedor['Contenedor']; ?></td><?php } ?>
				<?php if($mostrarIdioma) { ?><td><?php echo $contenedor['Idioma']; ?></td><?php } ?>
				<?php if($mostrarPrecinta) { ?><td><?php echo $contenedor['Precinta']; ?></td><?php } ?>
				<?php if($pedirLote) { ?><td><?php echo $contenedor['Lote']; ?></td><?php } ?>
				<?php if($pedirFechaCaducidad) { ?><td><?php echo formateaTipo($contenedor['FechaCaducidad'],'F'); ?></td><?php } ?>
                
                <?php if($mostrarPaisOrigen) { ?>
                <td><?php echo $contenedor['PaisOrigenCodigo']; ?></th>
                <?php } ?>
				
                <?php if($datoInformadoNumSerie) { ?><td><?php echo $contenedor['NumSerie']; ?></td><?php } ?>
				<?php if($datoInformadoEntrada) { ?><td><?php echo $contenedor['NumEntrada']; ?></td><?php } ?>
                <?php if($datoInformadoDocEntrada) { ?><td><?php echo $contenedor['NumDocEntrada']; ?></td><?php } ?>
                
                <td align="right"><?php echo formateaNumeroDecimal($contenedor['Stock']); ?><?php //echo number_format($contenedor['Stock'],0,',','.'); ?></td>
				
				<?php if($verEnCajas=='S') { ?><td align="right"><?php echo formateaNumeroDecimal($contenedor['StockCajas']); ?><?php //echo number_format($contenedor['StockCajas'],0,',','.'); ?></td><?php } ?>
                
                <?php if($permitirSeleccionarLote) { ?>
                <td><img src="<?php echo DIR_IMAGENES; ?>/select.png" alt="Seleccionar" width="50" height="50" class="clicable"/></td>
                <?php } ?>
            
			</tr>
			<?php
			$contador++;
		}
		?>
		</table>
        
        <br />
        
        <?php paginacion(); ?>
		
		<p><input type="submit" name="botonCerrarGrande" id="botonCerrarGrande" value="Cerrar" class="boton botonSecundario botonCerrarCombinaciones"/></p>
		
		<script>
		
		$(document).ready(function() {
		
			$('.botonCerrarCombinaciones').on('click',function(e){
				e.preventDefault();
				$('#popupBusqueda').hide();
				$('#popupBusquedaContenido').hide();
				<?php if($gestionPaletizado=='S') { ?>
					$('#contenedor').focus();
				<?php } else { ?>
					$('#ubicacion').focus();
				<?php } ?>
			});
			
			
			<?php if($permitirSeleccionarLote) { ?>
			
			$('.selectorLote').on('click',function(e){
		
				e.preventDefault();
				
				var foco='lote';
				
				var lote=$(this).attr('lote');
				$('#lote').val( lote );
				
				//17-06-2024 TICKET 24059681 esto nunca lo ha hecho, por mucho que Alvar diga que si. Hablo con IPM y lo ponemos para que se calle
				var caducidad=$(this).attr('caducidad');
				$('#fechaCaducidad').val( caducidad );
				var contenedor=$(this).attr('contenedor');
				$('#contenedor').val( contenedor );
				var ubicacion=$(this).attr('ubicacion');
				$('#ubicacion').val( ubicacion );
				
				<?php if($mostrarPaisOrigen) { ?>
				var paisOrigen=$(this).attr('paisOrigen');
				$('#paisOrigen').val( paisOrigen );
				<?php } ?>
				
				$('#popupBusqueda').hide();
				$('#popupBusquedaContenido').hide();
				
			});
			
			<?php } ?>
			
		});
		
	<?php } //Fin si no es el proceso de obtener datos únicos ?>
	
<?php } //Fin si no hay error ?> 

<?php /////////////////////// CUIDADO CON ESTAS LINEAS NO PONER SALTOS DE CARRO ////////////////////////// ?>